==> Smdn.Formats.Mime-0.21.tar.bz2: Smdn.Formats.Mime-0.21/Smdn.Core.Standards/Smdn.IO/LooseLineOrientedStream.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;

namespace Smdn.IO {
  public class LooseLineOrientedStream : LineOrientedStream {
    public LooseLineOrientedStream(Stream stream)
      : base(stream, null, false, DefaultBufferSize)
    {
    }

    public LooseLineOrientedStream(Stream stream, int bufferSize)
      : base(stream, null, false, bufferSize)
    {
    }
  }
}

==> Smdn.Formats.Mime-0.33.tar.bz2: Smdn.Formats.Mime-0.33/Smdn.Core.Standards/Smdn.IO/LooseLineOrientedStream.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2012 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;

namespace Smdn.IO {
  public class LooseLineOrientedStream : LineOrientedStream {
    public LooseLineOrientedStream(Stream stream)
      : base(stream, null, false, DefaultBufferSize, DefaultLeaveStreamOpen)
    {
    }

    public LooseLineOrientedStream(Stream stream, int bufferSize)
      : base(stream, null, false, bufferSize, DefaultLeaveStreamOpen)
    {
    }

    public LooseLineOrientedStream(Stream stream, bool leaveStreamOpen)
      : base(stream, null, false, DefaultBufferSize, leaveStreamOpen)
    {
    }
    
    public LooseLineOrientedStream(Stream stream, int bufferSize, bool leaveStreamOpen)
      : base(stream, null, false, bufferSize, leaveStreamOpen)
    {
    }
  }
}
